@@ -18,11 +18,6 @@ const DndTargetType = {
     IMAGE: 3,
 };
 
-// Silly paste.gnome.org limitation:
-// http://sayakb.github.io/sticky-notes/pages/api/#create-return-values-on-error
-// The visible title is even more limited than the 30-character hard limit ...
-const MAX_PASTE_TITLE_LENGTH = 25;
-
 const PasteManager = new Lang.Class({
     Name: 'PasteManager',
 
@@ -73,51 +68,14 @@ const PasteManager = new Lang.Class({
         this._widgets.push(widget);
     },
 
-    pasteText: function(text) {
-        let app = Gio.Application.get_default();
-        let n = new UploadNotification("text");
-        app.notificationQueue.addNotification(n);
-
-        this._pasteText(text, n);
-    },
-
-    _pasteText: function(text, notification) {
-        let room = this._roomManager.getActiveRoom();
-        if (!room) {
-            notification.close();
-            return;
+    pasteContent: function(content, title, callback) {
+        if (typeof content == 'string') {
+            Utils.gpaste(content, title, callback);
+        } else if (content instanceof GdkPixbuf.Pixbuf) {
+            Utils.imgurPaste(content, title, callback);
+        } else {
+            throw new Error('Unhandled content type');
         }
-
-        let title;
-        let nick = room.channel.connection.self_contact.alias;
-        if (room.type == Tp.HandleType.ROOM)
-            /* translators: %s is a nick, #%s a channel */
-            title = _("%s in #%s").format(nick, room.display_name);
-        else
-            title = _("Paste from %s").format(nick);
-
-        if (title.length > MAX_PASTE_TITLE_LENGTH)
-            title = title.substr(0, MAX_PASTE_TITLE_LENGTH - 1) + '…';
-
-        Utils.gpaste(text, title, Lang.bind(this,
-            function(url) {
-                if (!url) {
-                    notification.close();
-                    return;
-                }
-
-                let type = Tp.ChannelTextMessageType.NORMAL;
-                let message = Tp.ClientMessage.new_text(type, url);
-                room.channel.send_message_async(message, 0, Lang.bind(this,
-                    function(c, res) {
-                        try {
-                             c.send_message_finish(res);
-                        } catch(e) {
-                             logError(e, 'Failed to send message')
-                        }
-                        notification.close();
-                    }));
-            }));
     },
 
     _onDragDrop: function(widget, context, x, y, time) {
@@ -290,23 +248,3 @@ const PasteManager = new Lang.Class({
         }
     }
 });
-
-const UploadNotification = new Lang.Class({
-    Name: 'UploadNotification',
-    Extends: AppNotifications.AppNotification,
-
-    _init: function(content) {
-        this.parent();
-
-        this._grid = new Gtk.Grid({ orientation: Gtk.Orientation.HORIZONTAL,
-                                    column_spacing: 12 });
-
-        this._grid.add(new Gtk.Spinner({ active: true }));
-
-        let label = new Gtk.Label({ label: _("Uploading %s").format(content) });
-        this._grid.add(label);
-
-        this.widget.add(this._grid);
-        this.widget.show_all();
-    }
-});
